@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -22,12 +22,11 @@
 #include <QMap>
 #include <KEmailAddress>
 #include "libkdepimakonadi_debug.h"
-#include "helper_p.h"
+
 using namespace KPIM;
 
 BalooCompletionEmail::BalooCompletionEmail()
 {
-
 }
 
 void BalooCompletionEmail::setEmailList(const QStringList &lst)
@@ -90,10 +89,10 @@ QString BalooCompletionEmail::stripEmail(const QString &email, QString &address)
     QString displayName, addrSpec, comment;
     if (KEmailAddress::AddressOk == KEmailAddress::splitAddress(email, displayName, addrSpec, comment)) {
         address = addrSpec;
-        while ((displayName.startsWith(QLatin1Char('\'')) && displayName.endsWith(QLatin1Char('\''))) ||
-                (displayName.startsWith(QLatin1Char('"')) && displayName.endsWith(QLatin1Char('"'))) ||
-                (displayName.startsWith(QStringLiteral("\\\"")) && displayName.endsWith(QStringLiteral("\\\"")))) {
-            if (displayName.startsWith(QStringLiteral("\\\""))) {
+        while ((displayName.startsWith(QLatin1Char('\'')) && displayName.endsWith(QLatin1Char('\'')))
+               || (displayName.startsWith(QLatin1Char('"')) && displayName.endsWith(QLatin1Char('"')))
+               || (displayName.startsWith(QLatin1String("\\\"")) && displayName.endsWith(QLatin1String("\\\"")))) {
+            if (displayName.startsWith(QLatin1String("\\\""))) {
                 displayName = displayName.mid(2, displayName.length() - 4).trimmed();
             } else {
                 displayName = displayName.mid(1, displayName.length() - 2).trimmed();
@@ -104,4 +103,3 @@ QString BalooCompletionEmail::stripEmail(const QString &email, QString &address)
         return email;
     }
 }
-
